==> kotlin-compiler-0.14.449-sources.jar: org/jetbrains/kotlin/codegen/AccessorForConstructorDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.codegen

import org.jetbrains.kotlin.descriptors.*
import org.jetbrains.kotlin.name.Name
import org.jetbrains.kotlin.psi.JetSuperExpression
import org.jetbrains.kotlin.resolve.DescriptorUtils
import org.jetbrains.kotlin.types.JetType

public class AccessorForConstructorDescriptor(
        private val calleeDescriptor: ConstructorDescriptor,
        containingDeclaration: DeclarationDescriptor,
        private val superCallExpression: JetSuperExpression?
) : AbstractAccessorForFunctionDescriptor(containingDeclaration, Name.special("<init>")),
        ConstructorDescriptor,
        AccessorForCallableDescriptor<ConstructorDescriptor> {
    override fun getCalleeDescriptor(): ConstructorDescriptor = calleeDescriptor

    override fun getContainingDeclaration(): ClassDescriptor = calleeDescriptor.containingDeclaration

    override fun isPrimary(): Boolean = false

    override fun getReturnType(): JetType = super.getReturnType()!!

    override fun getSuperCallExpression(): JetSuperExpression? = superCallExpression

    init {
        initialize(
                DescriptorUtils.getReceiverParameterType(extensionReceiverParameter),
                calleeDescriptor.dispatchReceiverParameter,
                copyTypeParameters(calleeDescriptor),
                copyValueParameters(calleeDescriptor),
                calleeDescriptor.returnType,
                Modality.FINAL,
                Visibilities.INTERNAL,
                false
        )
    }
}

==> kotlin-compiler-1.0.5-3-sources.jar: org/jetbrains/kotlin/codegen/AccessorForConstructorDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.codegen

import org.jetbrains.kotlin.descriptors.*
import org.jetbrains.kotlin.name.Name
import org.jetbrains.kotlin.resolve.DescriptorUtils
import org.jetbrains.kotlin.types.KotlinType
import org.jetbrains.kotlin.types.TypeSubstitutor

class AccessorForConstructorDescriptor(
        private val calleeDescriptor: ConstructorDescriptor,
        containingDeclaration: DeclarationDescriptor,
        private val superCallTarget: ClassDescriptor?
) : AbstractAccessorForFunctionDescriptor(containingDeclaration, Name.special("<init>")),
        ConstructorDescriptor,
        AccessorForCallableDescriptor<ConstructorDescriptor> {
    override fun getCalleeDescriptor(): ConstructorDescriptor = calleeDescriptor

    override fun getContainingDeclaration(): ClassDescriptor = calleeDescriptor.containingDeclaration

    override fun isPrimary(): Boolean = false

    override fun getReturnType(): KotlinType = super.getReturnType()!!

    override fun getSuperCallTarget(): ClassDescriptor? = superCallTarget

    override fun substitute(substitutor: TypeSubstitutor) = super.substitute(substitutor) as ConstructorDescriptor

    override fun copy(
            newOwner: DeclarationDescriptor?, modality: Modality?, visibility: Visibility?, kind: CallableMemberDescriptor.Kind?, copyOverrides: Boolean
    ): AccessorForConstructorDescriptor {
        throw UnsupportedOperationException("Trying to copy synthetic accessor $this")
    }

    override fun getOriginal(): AccessorForConstructorDescriptor = this

    init {
        initialize(
                DescriptorUtils.getReceiverParameterType(extensionReceiverParameter),
                calleeDescriptor.dispatchReceiverParameter,
                copyTypeParameters(calleeDescriptor),
                copyValueParameters(calleeDescriptor),
                calleeDescriptor.returnType,
                Modality.FINAL,
                Visibilities.LOCAL
        )
    }
}
